package com.fs.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.system.domain.SysKeyword;

import java.util.List;

/**
 * 系统关键字Service接口
 *
 * @author fs
 * @date 2025-05-14
 */
public interface ISysKeywordService extends IService<SysKeyword>{
    /**
     * 查询系统关键字
     *
     * @param keywordId 系统关键字主键
     * @return 系统关键字
     */
    SysKeyword selectSysKeywordById(Long keywordId);

    /**
     * 查询系统关键字列表
     *
     * @param sysKeyword 系统关键字
     * @return 系统关键字集合
     */
    List<SysKeyword> selectSysKeywordList(SysKeyword sysKeyword);

    /**
     * 新增系统关键字
     *
     * @param sysKeyword 系统关键字
     * @return 结果
     */
    int insertSysKeyword(SysKeyword sysKeyword);

    /**
     * 修改系统关键字
     *
     * @param sysKeyword 系统关键字
     * @return 结果
     */
    int updateSysKeyword(SysKeyword sysKeyword);

    /**
     * 批量删除系统关键字
     *
     * @param keywordIds 需要删除的系统关键字主键集合
     * @return 结果
     */
    int deleteSysKeywordByIds(Long[] keywordIds);

    /**
     * 删除系统关键字信息
     *
     * @param keywordId 系统关键字主键
     * @return 结果
     */
    int deleteSysKeywordById(Long keywordId);

    /**
     * 查询指定ids的关键字
     * @param keywordIds
     * @return
     */
    List<SysKeyword> selectSysKeywordByIds(Long[] keywordIds);
}
